#
# spec file for package python-swapper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-swapper
Version:        1.4.0
Release:        1.2
Summary:        The unofficial Django swappable models API
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/wq/django-swappable-models
Source:         https://files.pythonhosted.org/packages/source/s/swapper/swapper-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 2.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.0
BuildArch:      noarch
%python_subpackages

%description
Swapper is an unofficial API for the undocumented but very
powerful Django feature: swappable models. Swapper facilitates
implementing arbitrary swappable models in your own reusable apps.

%prep
%setup -q -n swapper-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# can't use %%pyunittest: the SLE/Leap targets in d:l:p:django have old python-rpm-macros
%python_exec -m unittest -v tests.test_swapper

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/swapper
%{python_sitelib}/swapper-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Added support for Django 4.2 and 5.0.
  * Dropped support for Django Django 4.0a1.
  * Added support for Python 3.10 and 3.11.
  * Dropped support for Python 3.7.
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * [change] Allow possibility to point swappable dependency to
    specific migration number (instead of only to __latest__)
  * [feature] Add possibility to point swappable dependency to
    __latest__
  * [change] Added support for Python 3.9
  * [change] Added support for Django 3.2 and Django 4.0a1
  * [change] Dropped support for old Django versions (<2.2)
  * [change] Dropped support for old Python versions (<3.7)
  * [feature] Added optional require_ready argument to load_model
    function
  * [deps] Verified support for python 3.8
  * [deps] Added support for Django 3.0 and Django Rest Framework
    3.11
  * [deps] Drop python<3.3 support
  * [deps] Added support for python 3.7
  * [deps] Django 2 support added
  * [test] Added tests for swapper.split
  * #13 [fix] Handle contrib apps and apps with dot in app_label.
  * [docs] Improved usuability docs
  * 86e238: [deps] Compatibility with django 1.10 added
  * #9 [deps] Added support for django 1.9
  * [deps] Added support for django~=1.6.0
  * [deps] Added support for Python 3.3
  * [docs] Fix model reference in README
  * [docs] Notes for load_model initialization (for more info see
    [#2])
  * [docs] Added examples for migration scripts
  * [docs] Documented use of Functions
  * [fix] Fixed Lookup Error in load_model
  * [deps] Added support for Django 1.7
  * [feature] Added swapper.dependency function.
  * [tests] Added tests
  * [docs] Added References
  * Added base functions for swapping models
* Wed May  5 2021 Ben Greiner <code@bnavigator.de>
- Replace deprecated setup.py call. This additionally avoids
  the setuptools generated failure because Django's egg-info
  requirements are not fully fulfilled by the python-Django rpm.
* Thu Jan 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.2.post1:
  * Fix working with newer djangos
* Thu Aug  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.1:
  * Verify Django 2 support in tests (#17 via @gasman).
  * Test on Python 3.7 and drop Python 2.6 and 3.3.
* Thu Jun 20 2019 Marketa Calabkova <mcalabkova@suse.com>
- Initial packaging (v1.1)
